@@ -467,10 +467,9 @@ sinfo_fill_am(Sinfo *sinfo, char *am_map)
   sinfo->am = g_hash_table_lookup(am_hash, &sinfo->sloc.eng_off);
   if (sinfo->am == NULL)
     {
-      sinfo->am = fmalloc0(sizeof(*sinfo->am));
-      g_hash_table_insert(am_hash, &sinfo->sloc.eng_off, sinfo->am);
       sinfo_split_fill(sinfo, 
 	am_map + sinfo->sloc.eng_off, sinfo_am_fill_from_fields);
+      g_hash_table_insert(am_hash, &sinfo->sloc.eng_off, sinfo->am);
     }
 
   return sinfo;
@@ -487,10 +486,9 @@ sinfo_fill_fm(Sinfo *sinfo, char *fm_map)
   sinfo->fm = g_hash_table_lookup(fm_hash, &sinfo->sloc.eng_off);
   if (sinfo->fm == NULL)
     {
-      sinfo->fm = fmalloc0(sizeof(*sinfo->fm));
-      g_hash_table_insert(fm_hash, &sinfo->sloc.eng_off, sinfo->fm);
       sinfo_split_fill(sinfo,
 	fm_map + sinfo->sloc.eng_off, sinfo_fm_fill_from_fields);
+      g_hash_table_insert(fm_hash, &sinfo->sloc.eng_off, sinfo->fm);
     }
 
   return sinfo;
@@ -507,10 +505,9 @@ sinfo_fill_tv(Sinfo *sinfo, char *tv_map)
   sinfo->tv = g_hash_table_lookup(tv_hash, &sinfo->sloc.eng_off);
   if (sinfo->tv == NULL)
     {
-      sinfo->tv = fmalloc0(sizeof(*sinfo->tv));
-      g_hash_table_insert(tv_hash, &sinfo->sloc.eng_off, sinfo->tv);
       sinfo_split_fill(sinfo,
 	tv_map + sinfo->sloc.eng_off, sinfo_tv_fill_from_fields);
+      g_hash_table_insert(tv_hash, &sinfo->sloc.eng_off, sinfo->tv);
     }
 
   return sinfo;
@@ -521,7 +518,7 @@ sinfo_near(Search *search, int *n_sinfo_ptr)
 {
   char *fac_map, *am_map, *fm_map, *tv_map;
   int fac_fd, am_fd, fm_fd, tv_fd, r, n_sinfo = 0;
-  Sinfo **sinfos = NULL;
+  Sinfo **sinfos = fmalloc(sizeof(*sinfos));
 
   if (!map_file(PKGDATADIR "/facility.dat", &fac_map, &fac_fd))
     return NULL;
@@ -656,12 +653,7 @@ sort_and_show_sinfo(Search *search, Sinfo **sinfos, int n_sinfos,
   static Sinfo **kept;
   int s, k, n_kept, last_freq;
 
-  if (sinfos == NULL)
-    {
-      sinfos_display(search, sinfos, -1, -1);
-      return;
-    }
-
+  printf("sort-and-show-sinfo: got %i at %p\n", n_sinfos, sinfos);
   local_search = search;
   if (n_sinfos < search->keep)
     {
@@ -700,7 +692,7 @@ sort_and_show_sinfo(Search *search, Sinfo **sinfos, int n_sinfos,
 int
 search_sort_and_show_sinfo(Search *search, Sinfos_display sinfos_display)
 {
-  int n;
+  int n = 0;
   Sinfo **sinfos = sinfo_near(search, &n);
   sort_and_show_sinfo(search, sinfos, n, sinfos_display);
   return n;
